<?php
unset($pia_lang);
//////////////////////////////////////////////////////////////////
// About - Update by @TeroRERO 07ago2022
//////////////////////////////////////////////////////////////////
$pia_lang['About_Title'] = 'Guadián de Red <br>(Código Abierto)';
$pia_lang['About_Design'] = 'Diseñado para:';
$pia_lang['About_Exit'] = 'Salir';
$pia_lang['About_Reports'] = 'Notificaciones';

//////////////////////////////////////////////////////////////////
// General - Update by @TeroRERO 01ago2022
//////////////////////////////////////////////////////////////////
$pia_lang['Gen_Delete'] = 'Eliminar';
$pia_lang['Gen_Cancel'] = 'Cancelar';
$pia_lang['Gen_Okay'] = 'Ok';
$pia_lang['Gen_Purge'] = 'Purgar';
$pia_lang['Gen_Backup'] = 'Ejecutar copia de seguridad';
$pia_lang['Gen_Restore'] = 'Ejecutar restauración';
$pia_lang['Gen_Switch'] = 'Cambiar';
$pia_lang['Gen_Run'] = 'Run';
$pia_lang['Gen_Save'] = 'Salvar';
$pia_lang['Gen_Close'] = 'Cerrar';
$pia_lang['Gen_on'] = 'On';
$pia_lang['Gen_off'] = 'Off';

//////////////////////////////////////////////////////////////////
// Login Page - Update by @TeroRERO 03ago2022
//////////////////////////////////////////////////////////////////

$pia_lang['Login_Box'] = 'Ingrese su contraseña';
$pia_lang['Login_Remember'] = 'Recordar';
$pia_lang['Login_Remember_small'] = '(válido por 7 días)';
$pia_lang['Login_Submit'] = 'Ingresar';
$pia_lang['Login_Psw_run'] = 'Para cambiar contraseña ejecute:';
$pia_lang['Login_Psw_new'] = 'nueva_contraseña';
$pia_lang['Login_Psw_folder'] = 'en la carpeta back.';
$pia_lang['Login_Psw_alert'] = '¡Alerta de Contraseña!';
$pia_lang['Login_Psw-box'] = 'Contraseña';
$pia_lang['Login_Toggle_Info'] = 'Información sobre la contraseña';
$pia_lang['Login_Toggle_Info_headline'] = 'Información sobre la contraseña';
$pia_lang['Login_Toggle_Alert_headline'] = 'Alerta de Contraseña!';

//////////////////////////////////////////////////////////////////
// Sidebar
//////////////////////////////////////////////////////////////////

$pia_lang['Navigation_Devices'] = 'Dispositivos';
$pia_lang['Navigation_Services'] = 'Web Services';
$pia_lang['Navigation_Presence'] = 'Historial';
$pia_lang['Navigation_Events'] = 'Eventos';
$pia_lang['Navigation_Journal'] = 'Pi.Alert Journal';
$pia_lang['Navigation_Events_Dev'] = 'Devices';
$pia_lang['Navigation_Events_Serv'] = 'Web Services';
$pia_lang['Navigation_ICMPScan'] = 'ICMP Monitoring';
$pia_lang['Navigation_Maintenance'] = 'Mantenimiento';
$pia_lang['Navigation_Network'] = 'Red';
$pia_lang['Navigation_HelpFAQ'] = 'Ayuda / FAQ';
$pia_lang['Navigation_UpdateCheck'] = 'Update Check';
$pia_lang['Navigation_Section_A'] = 'MENÚ PRINCIPAL';
$pia_lang['Navigation_Section_B'] = 'EVENTOS Y REVISTA';
$pia_lang['Navigation_Section_C'] = 'AJUSTES Y AYUDA';

//////////////////////////////////////////////////////////////////
// Device Page - Update by @TeroRERO 03ago2022
//////////////////////////////////////////////////////////////////

$pia_lang['Device_Title'] = 'Dispositivos';
$pia_lang['Device_Shortcut_AllDevices'] = 'Todos';
$pia_lang['Device_Shortcut_Connected'] = 'Conectado(s)';
$pia_lang['Device_Shortcut_Favorites'] = 'Favorito(s)';
$pia_lang['Device_Shortcut_NewDevices'] = 'Nuevo(s)';
$pia_lang['Device_Shortcut_DownAlerts'] = 'Alerta(s) de caída(s)';
$pia_lang['Device_Shortcut_Archived'] = 'Archivado(s)';
$pia_lang['Device_Shortcut_Devices'] = 'Dispositivos';
$pia_lang['Device_Shortcut_OnlineChart_a'] = 'Presencia del dispositivo a lo largo del tiempo';
$pia_lang['Device_Shortcut_OnlineChart_b'] = 'h)'; //
$pia_lang['Device_TableHead_Name'] = 'Nombre';
$pia_lang['Device_TableHead_Owner'] = 'Propietario';
$pia_lang['Device_TableHead_Type'] = 'Tipo';
$pia_lang['Device_TableHead_Favorite'] = 'Favorito';
$pia_lang['Device_TableHead_Group'] = 'Grupo';
$pia_lang['Device_TableHead_Location'] = 'Ubicación';
$pia_lang['Device_TableHead_FirstSession'] = '1ra. sesión';
$pia_lang['Device_TableHead_LastSession'] = 'Última sesión';
$pia_lang['Device_TableHead_LastIP'] = 'Última IP';
$pia_lang['Device_TableHead_MAC'] = 'MAC';
$pia_lang['Device_TableHead_MACaddress'] = 'MAC-Address';
$pia_lang['Device_TableHead_LastIPOrder'] = 'Última orden de IP';
$pia_lang['Device_TableHead_Rowid'] = 'Rowid';
$pia_lang['Device_TableHead_Status'] = 'Estado';
$pia_lang['Device_TableHead_ConnectionType'] = 'Connection Type';
$pia_lang['Device_Searchbox'] = 'Búsqueda';
$pia_lang['Device_Tablelenght'] = 'Mostrar _MENU_ entradas';
$pia_lang['Device_Tablelenght_all'] = 'Todos';
$pia_lang['Device_Table_info'] = 'Mostrando el INICIO y el FINAL de TODAS las entradas';
$pia_lang['Device_Table_nav_next'] = 'Siguiente';
$pia_lang['Device_Table_nav_prev'] = 'Anterior';
$pia_lang['Device_bulkEditor_mode'] = 'Bulk Editor';
$pia_lang['Device_bulkEditor_mode_quit'] = 'Quit Editor';
$pia_lang['Device_bulkEditor_selectall'] = 'Select all Host&apos;s';
$pia_lang['Device_bulkEditor_selectnone'] = 'Deselect all Host&apos;s';
$pia_lang['Device_bulkEditor_savebox_title'] = 'Fields were saved';
$pia_lang['Device_bulkEditor_savebox_noselection'] = 'No fields were selected for modification';
$pia_lang['Device_bulkEditor_savebox_mod_devices'] = 'Modified devices';
$pia_lang['Device_bulkEditor_savebox_mod_fields'] = 'Changed values';
$pia_lang['Device_bulkEditor_hostbox_title'] = 'Select the devices to be edited';
$pia_lang['Device_bulkEditor_inputbox_title'] = 'Edit fields';
$pia_lang['Device_bulkDel_button'] = 'BORRAR DISPOSITIVOS';
$pia_lang['Device_bulkDel_info_head'] = 'Borrar varios dispositivos';
$pia_lang['Device_bulkDel_info_text'] = 'Con esta función se borran uno o varios aparatos de la base de datos. Si los aparatos siguen en la red, pueden volver a añadirse a la base de datos, pero sin los ajustes individuales.';
$pia_lang['Device_bulkDel_back_before'] = 'Número de unidades antes';
$pia_lang['Device_bulkDel_back_after'] = 'Número actual de unidades';
$pia_lang['Device_bulkDel_back_hosts'] = 'Direcciones MAC a eliminar';

//////////////////////////////////////////////////////////////////
// Presence Page - Update by @TeroRERO 25jul2022
//////////////////////////////////////////////////////////////////

$pia_lang['Presence_Title'] = 'Historial por dispositivo';
$pia_lang['Presence_Shortcut_AllDevices'] = 'Todos';
$pia_lang['Presence_Shortcut_Connected'] = 'Conectado(s)';
$pia_lang['Presence_Shortcut_Favorites'] = 'Favorito(s)';
$pia_lang['Presence_Shortcut_NewDevices'] = 'Nuevo(s)';
$pia_lang['Presence_Shortcut_DownAlerts'] = 'Alerta(s) de caída(s)';
$pia_lang['Presence_Shortcut_Archived'] = 'Archivado(s)';
$pia_lang['Presence_Shortcut_Devices'] = 'Dispositivos';

// Localizationfiles under pialert/front/lib/AdminLTE/bower_components/fullcalendar/dist/locale
$pia_lang['Presence_CallHead_Devices'] = 'Dispositivos';
$pia_lang['Presence_CalHead_lang'] = 'es-es';
$pia_lang['Presence_CalHead_year'] = 'año';
$pia_lang['Presence_CalHead_quarter'] = 'trimestre';
$pia_lang['Presence_CalHead_month'] = 'mes';
$pia_lang['Presence_CalHead_week'] = 'semana';
$pia_lang['Presence_CalHead_day'] = 'day';

//////////////////////////////////////////////////////////////////
// Events Page - Update by @TeroRERO 25jul2022
//////////////////////////////////////////////////////////////////

$pia_lang['Events_Title'] = 'Eventos';
$pia_lang['Events_Periodselect_today'] = 'Hoy';
$pia_lang['Events_Periodselect_LastWeek'] = 'La semana pasada';
$pia_lang['Events_Periodselect_LastMonth'] = 'El mes pasado';
$pia_lang['Events_Periodselect_LastYear'] = 'El año pasado';
$pia_lang['Events_Periodselect_All'] = 'Toda la información';
$pia_lang['Events_Shortcut_AllEvents'] = 'Todos los eventos';
$pia_lang['Events_Shortcut_Sessions'] = 'Sesiones';
$pia_lang['Events_Shortcut_MissSessions'] = 'Sesiones faltantes';
$pia_lang['Events_Shortcut_VoidSessions'] = 'Sesiones anuladas';
$pia_lang['Events_Shortcut_NewDevices'] = 'Nuevo(s)';
$pia_lang['Events_Shortcut_DownAlerts'] = 'Alerta(s) de caída(s)';
$pia_lang['Events_Shortcut_Events'] = 'Eventos';
$pia_lang['Events_TableHead_Order'] = 'Ordenar';
$pia_lang['Events_TableHead_Device'] = 'Dispositivo';
$pia_lang['Events_TableHead_Owner'] = 'Propietario';
$pia_lang['Events_TableHead_Date'] = 'Fecha';
$pia_lang['Events_TableHead_EventType'] = 'Tipo de evento';
$pia_lang['Events_TableHead_Connection'] = 'Conexión';
$pia_lang['Events_TableHead_Disconnection'] = 'Desconexión';
$pia_lang['Events_TableHead_Duration'] = 'Duración';
$pia_lang['Events_TableHead_DurationOrder'] = 'Orden de duración';
$pia_lang['Events_TableHead_IP'] = 'Dirección IP';
$pia_lang['Events_TableHead_IPOrder'] = 'Orden de IP';
$pia_lang['Events_TableHead_AdditionalInfo'] = 'Información adicional';
$pia_lang['Events_Searchbox'] = 'Búsqueda';
$pia_lang['Events_Tablelenght'] = 'Mostrando entradas del MENÚ';
$pia_lang['Events_Tablelenght_all'] = 'Todos';
$pia_lang['Events_Table_info'] = 'Mostrar de _START_ a _END_ de _TOTAL_ entradas';
$pia_lang['Events_Table_nav_next'] = 'Siguiente';
$pia_lang['Events_Table_nav_prev'] = 'Anterior';

//////////////////////////////////////////////////////////////////
// WebServices Events Page
//////////////////////////////////////////////////////////////////

$pia_lang['WebServices_Events_Title'] = 'Servicios web - Eventos';
$pia_lang['WebServices_Events_Shortcut_All'] = 'Todos los eventos';
$pia_lang['WebServices_Events_Shortcut_HTTP2xx'] = 'HTTP Code 2xx';
$pia_lang['WebServices_Events_Shortcut_HTTP3xx'] = 'HTTP Code 3xx';
$pia_lang['WebServices_Events_Shortcut_HTTP4xx'] = 'HTTP Code 4xx';
$pia_lang['WebServices_Events_Shortcut_HTTP5xx'] = 'HTTP Code 5xx';
$pia_lang['WebServices_Events_Shortcut_Down'] = 'Down';
$pia_lang['WebServices_Events_TableHead_URL'] = 'URL';
$pia_lang['WebServices_Events_TableHead_TargetIP'] = 'IP objetivo';
$pia_lang['WebServices_Events_TableHead_ScanTime'] = 'Tiempo de exploración';
$pia_lang['WebServices_Events_TableHead_StatusCode'] = 'Código de estatus';
$pia_lang['WebServices_Events_TableHead_ResponsTime'] = 'Tiempo de reacción';

//////////////////////////////////////////////////////////////////
// Device Details Page - Update by @TeroRERO 01ago2022
//////////////////////////////////////////////////////////////////

$pia_lang['DevDetail_Periodselect_today'] = 'Hoy';
$pia_lang['DevDetail_Periodselect_LastWeek'] = 'La semana pasada';
$pia_lang['DevDetail_Periodselect_LastMonth'] = 'El mes pasado';
$pia_lang['DevDetail_Periodselect_LastYear'] = 'El año pasado';
$pia_lang['DevDetail_Periodselect_All'] = 'Toda la información';
$pia_lang['DevDetail_Shortcut_CurrentStatus'] = 'Estado actual';
$pia_lang['DevDetail_Shortcut_Sessions'] = 'Sesiones';
$pia_lang['DevDetail_Shortcut_Presence'] = 'Historial';
$pia_lang['DevDetail_Shortcut_DownAlerts'] = 'Alerta(s) de caída(s)';
$pia_lang['DevDetail_Tab_Details'] = 'Detalles';
$pia_lang['DevDetail_Tab_Nmap'] = 'Tools';
$pia_lang['DevDetail_Tab_Sessions'] = 'Sesiones';
$pia_lang['DevDetail_Tab_Presence'] = 'Historial';
$pia_lang['DevDetail_Tab_Events'] = 'Eventos';
$pia_lang['DevDetail_MainInfo_Title'] = 'Información principal';
$pia_lang['DevDetail_MainInfo_mac'] = 'MAC';
$pia_lang['DevDetail_MainInfo_Name'] = 'Nombre';
$pia_lang['DevDetail_MainInfo_Owner'] = 'Propietario';
$pia_lang['DevDetail_MainInfo_Type'] = 'Tipo';
$pia_lang['DevDetail_MainInfo_Vendor'] = 'Proveedor';
$pia_lang['DevDetail_MainInfo_Model'] = 'Model';
$pia_lang['DevDetail_MainInfo_Serialnumber'] = 'Serial';
$pia_lang['DevDetail_MainInfo_Favorite'] = 'Favorito';
$pia_lang['DevDetail_MainInfo_Group'] = 'Grupo';
$pia_lang['DevDetail_MainInfo_Location'] = 'Ubicación';
$pia_lang['DevDetail_MainInfo_Comments'] = 'Comentario';
$pia_lang['DevDetail_MainInfo_Network'] = 'Hardware de Red (ID)';
$pia_lang['DevDetail_MainInfo_Network_Port'] = 'Puerto de Red HW';
$pia_lang['DevDetail_MainInfo_Network_ConnectType'] = 'Connection Type';
$pia_lang['DevDetail_SessionInfo_Title'] = 'Información de sesión';
$pia_lang['DevDetail_SessionInfo_Status'] = 'Estado';
$pia_lang['DevDetail_SessionInfo_FirstSession'] = '1ra. sesión';
$pia_lang['DevDetail_SessionInfo_LastSession'] = 'Última sesión';
$pia_lang['DevDetail_SessionInfo_LastIP'] = 'Última IP';
$pia_lang['DevDetail_SessionInfo_StaticIP'] = 'IP estática';
$pia_lang['DevDetail_Network_Titel'] = 'Red';
$pia_lang['DevDetail_EveandAl_Title'] = 'Configuración de eventos y alertas';
$pia_lang['DevDetail_EveandAl_ScanCycle'] = 'Ciclo de escaneo';
$pia_lang['DevDetail_EveandAl_AlertAllEvents'] = 'Alerta a todos los eventos';
$pia_lang['DevDetail_EveandAl_AlertDown'] = 'Alerta de caída';
$pia_lang['DevDetail_EveandAl_Skip'] = 'Omitir notificaciones repetidas durante';
$pia_lang['DevDetail_EveandAl_NewDevice'] = 'Nuevo dispositivo';
$pia_lang['DevDetail_EveandAl_Archived'] = 'Archivada';
$pia_lang['DevDetail_EveandAl_RandomMAC'] = 'MAC al azar';
$pia_lang['DevDetail_EveandAl_ScanCycle_a'] = 'Escanear Dispositivo (1 min)';
$pia_lang['DevDetail_EveandAl_ScanCycle_z'] = 'No Escanear Dispositivo (0 min)';
$pia_lang['DevDetail_button_Delete'] = 'Eliminar dispositivo';
$pia_lang['DevDetail_button_Delete_Warning'] = '¿Estás seguro de que quieres borrar este dispositivo?<br>(tal vez prefieras archivarlo)';
$pia_lang['DevDetail_button_DeleteEvents'] = 'Eliminar eventos';
$pia_lang['DevDetail_button_DeleteEvents_Warning'] = '¿Estás seguro de que quieres borrar todos los Eventos de este dispositivo? Esto borrará el historial de Eventos y las Sesiones y podría ayudar con las notificaciones constantes (persistentes).';
$pia_lang['DevDetail_button_Reset'] = 'Restablecer cambios';
$pia_lang['DevDetail_button_Save'] = 'Guardar';
$pia_lang['DevDetail_SessionTable_Order'] = 'Ordenar';
$pia_lang['DevDetail_SessionTable_Connection'] = 'Conexión';
$pia_lang['DevDetail_SessionTable_Disconnection'] = 'Desconexión';
$pia_lang['DevDetail_SessionTable_Duration'] = 'Duración';
$pia_lang['DevDetail_SessionTable_IP'] = 'Dirección IP';
$pia_lang['DevDetail_SessionTable_Additionalinfo'] = 'Información adicional';
$pia_lang['DevDetail_Events_CheckBox'] = 'Ocultar eventos de conexión';
$pia_lang['DevDetail_Tools_nmap_buttonFast'] = 'Exploración rápida';
$pia_lang['DevDetail_Tools_nmap_buttonDefault'] = 'Escaneado predeterminado';
$pia_lang['DevDetail_Tools_nmap_buttonDetail'] = 'Escaneo detallado';
$pia_lang['DevDetail_Tools_nmap_buttonFast_text'] = 'Escaneo rápido: escanee menos puertos (100) que el escaneo predeterminado (unos pocos segundos)';
$pia_lang['DevDetail_Tools_nmap_buttonDefault_text'] = 'Escaneo predeterminado: NMAP escanea los 1,000 puertos principales para cada protocolo de escaneo solicitado. Esto atrapa aproximadamente el 93% de los puertos TCP y el 49% de los puertos UDP. (aproximadamente 5 segundos)';
$pia_lang['DevDetail_Tools_nmap_buttonDetail_text'] = 'Escaneo detallado: escaneo predeterminado con detección de sistema operativo habilitado, detección de versiones, escaneo de script y traceroute (hasta 30 segundos o más)';
$pia_lang['DevDetail_Tools_WOL'] = 'Send Wol command to ';
$pia_lang['DevDetail_Tools_WOL_noti'] = 'Wake-on-LAN';
$pia_lang['DevDetail_Tools_WOL_noti_text'] = 'The Wake-on-LAN command is sent to the broadcast address. If the target is not in the subnet/vlan of Pi.Alert, the target device will not respond.';
$pia_lang['BackDevDetail_Tools_WOL_okay'] = 'The command was executed';
$pia_lang['BackDevDetail_Tools_WOL_error'] = 'The command was not executed';

//////////////////////////////////////////////////////////////////
// WebServices Details Page
//////////////////////////////////////////////////////////////////

$pia_lang['WebServices_Title'] = 'Servicios web';
$pia_lang['WebServices_unknown_Device'] = 'Unknown Device';
$pia_lang['WebServices_tablehead_TargetIP'] = 'Target IP';
$pia_lang['WebServices_tablehead_ScanTime'] = 'Scan Time';
$pia_lang['WebServices_tablehead_Status_Code'] = 'HTTP Status';
$pia_lang['WebServices_tablehead_Response_Time'] = 'Response Time';
$pia_lang['WebServices_Tab_Graph'] = 'Stats';
$pia_lang['WebServices_label_URL'] = 'URL';
$pia_lang['WebServices_label_Tags'] = 'Tag';
$pia_lang['WebServices_label_MAC'] = 'Device';
$pia_lang['WebServices_label_MAC_Select'] = 'Select';
$pia_lang['WebServices_label_Notes'] = 'Note';
$pia_lang['WebServices_label_TargetIP'] = 'IP objetivo';
$pia_lang['WebServices_label_StatusCode'] = 'HTTP Status';
$pia_lang['WebServices_label_ScanTime'] = 'Tiempo de exploración';
$pia_lang['WebServices_label_Response_Time'] = 'Tiempo de reacción';
$pia_lang['WebServices_label_AlertEvents'] = 'All Events';
$pia_lang['WebServices_label_AlertDown'] = 'Down Events';
$pia_lang['WebServices_label_Notification'] = 'Notify';
$pia_lang['WebServices_Chart_a'] = 'Service Status over the last';
$pia_lang['WebServices_Chart_b'] = 'hours';
$pia_lang['WebServices_Page_down'] = 'Offline';
$pia_lang['WebServices_button_Delete_label'] = 'Suprimir servicio';
$pia_lang['WebServices_button_Delete_Warning'] = 'Are you sure you want to delete this web service?';
$pia_lang['WebServices_headline_NewService'] = 'Nuevo servicio web';
$pia_lang['WebServices_Events_all'] = 'All Events';
$pia_lang['WebServices_Events_down'] = 'Down';
$pia_lang['WebServices_Events_none'] = 'none';
$pia_lang['WebServices_BoxTitle_General'] = 'General';
$pia_lang['WebServices_Stats_Code'] = 'Page Status';
$pia_lang['WebServices_Stats_Time'] = 'Response Time';
$pia_lang['WebServices_Stats_Time_min'] = 'Fastest';
$pia_lang['WebServices_Stats_Time_max'] = 'Slowest';
$pia_lang['WebServices_Stats_Location'] = 'Ubicación';
$pia_lang['WebServices_Stats_IP'] = 'IP actual';
$pia_lang['WebServices_Stats_IPLocation'] = 'Asignación de país';
$pia_lang['WebServices_Stats_comment_a'] = '(Calculado a partir de todos los escaneos de este servicio)';

//////////////////////////////////////////////////////////////////
// WebServices Details Page - Backend
//////////////////////////////////////////////////////////////////

$pia_lang['BackWebServices_UpdServ'] = 'The web service was updated';
$pia_lang['BackWebServices_UpdServError'] = 'The web service was not updated';
$pia_lang['BackWebServices_InsServ'] = 'The web service was saved';
$pia_lang['BackWebServices_InsServError'] = 'The web service was not saved';
$pia_lang['BackWebServices_DelServ'] = 'The web service was deleted from the database';
$pia_lang['BackWebServices_DelServError'] = 'The web service could not be deleted, or could not be deleted completely';

//////////////////////////////////////////////////////////////////
// Página de Monitoreo ICMP
//////////////////////////////////////////////////////////////////

$pia_lang['ICMPMonitor_Title'] = 'Monitor ICMP';
$pia_lang['ICMPMonitor_headline_IP'] = 'Monitorear nueva dirección IP';
$pia_lang['ICMPMonitor_label_IP'] = 'IP del Host';
$pia_lang['ICMPMonitor_label_Hostname'] = 'Nombre de Host';
$pia_lang['ICMPMonitor_label_RTT'] = 'RTT promedio';
$pia_lang['BackICMP_mon_disabled'] = 'El monitoreo ICMP está desactivado';
$pia_lang['BackICMP_mon_enabled'] = 'El monitoreo ICMP está activado';
$pia_lang['BackICMP_mon_InsICMP'] = 'El host ICMP ha sido guardado';
$pia_lang['BackICMP_mon_InsICMPError'] = 'El host ICMP no fue guardado';
$pia_lang['BackICMP_mon_DelICMP'] = 'El host ICMP ha sido eliminado de la base de datos';
$pia_lang['BackICMP_mon_DelICMPError'] = 'No se pudo eliminar el host ICMP, o no se eliminó completamente';
$pia_lang['BackICMP_mon_UpdICMP'] = 'El host ICMP ha sido actualizado';
$pia_lang['BackICMP_mon_UpdICMPError'] = 'No se pudo actualizar el host ICMP';
$pia_lang['ICMPMonitor_Shortcut_Online'] = 'En línea';
$pia_lang['ICMPMonitor_Shortcut_Offline'] = 'Fuera de línea/No disponible';
$pia_lang['ICMPMonitor_Availability'] = 'Availability';

/////////////////////////////////////////////////////////////////////////////
// Maintenance Page - Update by @TeroRERO 07ago2022 and leiweibau 29ago2022
/////////////////////////////////////////////////////////////////////////////

$pia_lang['Maintenance_Title'] = 'Herramientas de mantenimiento';
$pia_lang['Maintenance_database_path'] = 'Ruta de la base de datos:';
$pia_lang['Maintenance_database_size'] = 'Tamaño de base de datos:';
$pia_lang['Maintenance_database_lastmod'] = 'Última modificación:';
$pia_lang['Maintenance_database_backup'] = 'Copias de seguridad de la BD:';
$pia_lang['Maintenance_config_backup'] = 'Config Backups';
$pia_lang['Maintenance_database_backup_found'] = 'copia(s) de seguridad encontrada(s)';
$pia_lang['Maintenance_database_backup_total'] = 'Uso total de disco';
$pia_lang['Maintenance_arp_status'] = 'Estado de escaneo:';
$pia_lang['Maintenance_arp_status_off'] = 'está actualmente deshabilitado';
$pia_lang['Maintenance_arp_status_on'] = 'escaneo(s) actualmente en ejecución';
$pia_lang['Maintenance_notification_config'] = 'Notifications (Devices, ICMP)';
$pia_lang['Maintenance_notification_config_webmon'] = 'Notifications (Service Mon.)';
$pia_lang['Maintenance_Tools_Logviewer_Scan'] = 'Scan';
$pia_lang['Maintenance_Tools_Logviewer_Scan_empty'] = 'Se está realizando una exploración';
$pia_lang['Maintenance_Tools_Logviewer_IPLog'] = 'Internet IP';
$pia_lang['Maintenance_Tools_Logviewer_IPLog_empty'] = 'No hay protocolo disponible';
$pia_lang['Maintenance_Tools_Logviewer_Vendor'] = 'Vendor Update';
$pia_lang['Maintenance_Tools_Logviewer_Vendor_empty'] = 'No hay protocolo disponible';
$pia_lang['Maintenance_Tools_Logviewer_Cleanup'] = 'Cleanup';
$pia_lang['Maintenance_Tools_Logviewer_Cleanup_empty'] = 'No hay protocolo disponible';
$pia_lang['Maintenance_Tools_Logviewer_Nmap'] = 'Nmap (sesión)';
$pia_lang['Maintenance_Tools_Logviewer_Nmap_empty'] = 'No hay protocolo disponible';
$pia_lang['Maintenance_Tools_Logviewer_WebServices'] = 'Web Services';
$pia_lang['Maintenance_Tools_Logviewer_WebServices_empty'] = 'No hay protocolo disponible';
$pia_lang['Maintenance_Tools_Logviewer_WOL'] = 'Wake-on-LAN (sesión)';
$pia_lang['Maintenance_Tools_Logviewer_WOL_empty'] = 'No hay protocolo disponible';
$pia_lang['Maintenance_themeselector_lable'] = 'Seleccionar Skin';
$pia_lang['Maintenance_themeselector_empty'] = 'Elija un Skin';
$pia_lang['Maintenance_themeselector_apply'] = 'Aplicar';
$pia_lang['Maintenance_lang_selector_lable'] = 'Seleccione su idioma';
$pia_lang['Maintenance_lang_selector_empty'] = 'Elija un idioma';
$pia_lang['Maintenance_lang_en_us'] = 'Inglés (US)';
$pia_lang['Maintenance_lang_de_de'] = 'Alemán (DE)';
$pia_lang['Maintenance_lang_es_es'] = 'Español (ES)';
$pia_lang['Maintenance_lang_fr_fr'] = 'Francés (FR)';
$pia_lang['Maintenance_lang_selector_apply'] = 'Aplicar';
$pia_lang['Maintenance_Tools_Tab_Settings'] = 'Ajustes';
$pia_lang['Maintenance_Tools_Tab_Tools'] = 'Tools';
$pia_lang['Maintenance_Tools_Tab_BackupRestore'] = 'Respaldo / Restaurar';
$pia_lang['Maintenance_Tools_Tab_Subheadline_a'] = 'General';
$pia_lang['Maintenance_Tools_Tab_Subheadline_b'] = 'Configurar la vista general del dispositivo';
$pia_lang['Maintenance_Tools_Tab_Subheadline_c'] = 'Seguridad';
$pia_lang['Maintenance_Tools_Tab_Subheadline_d'] = 'Modules';
$pia_lang['Maintenance_Tools_Tab_Settings_Intro'] = 'Las opciones enumeradas aquí efectúan cambios en la configuración del servidor. Por lo tanto, estos cambios afectan a todos los dispositivos que accedan a esta página.';
$pia_lang['Maintenance_Tool_darkmode'] = 'Dark Mode';
$pia_lang['Maintenance_Tool_darkmode_noti'] = 'Cambiar Modo';
$pia_lang['Maintenance_Tool_darkmode_noti_text'] = 'Después del cambio de tema, la página intenta volver a cargar para activar el cambio. Si es necesario, el caché debe ser eliminado.';
$pia_lang['Maintenance_Tool_onlinehistorygraph'] = 'Gráfico de actividad';
$pia_lang['Maintenance_Tool_onlinehistorygraph_noti'] = 'Visualización de gráficos';
$pia_lang['Maintenance_Tool_onlinehistorygraph_noti_text'] = 'Activa/desactiva el gráfico para mostrar la actividad online/offline de las últimas 12h.';
$pia_lang['Maintenance_Tool_webservicemon'] = 'Web Service Mon.';
$pia_lang['Maintenance_Tool_webservicemon_noti'] = 'Web Service Monitoring';
$pia_lang['Maintenance_Tool_webservicemon_noti_text'] = 'Enables or disables the web service monitoring for Pi.Alert. With activation, additional elements are displayed in the interface. With deactivation, they disappear again.';
$pia_lang['Maintenance_Tool_icmpmon'] = 'Monitoreo ICMP';
$pia_lang['Maintenance_Tool_icmpmon_noti'] = 'Monitoreo ICMP';
$pia_lang['Maintenance_Tool_mainscan'] = 'Escaneo Principal';
$pia_lang['Maintenance_Tool_mainscan_noti'] = 'Escaneo Principal';
$pia_lang['Maintenance_Tool_mainscan_noti_text'] = 'Activa o desactiva el método principal de escaneo para Pi.Alert (escaneo ARP). La recopilación de datos de fuentes externas configuradas sigue activa.';
$pia_lang['Maintenance_Tool_icmpmon_noti_text'] = 'Habilita o deshabilita el monitoreo ICMP para Pi.Alert. Al habilitarlo, se mostrarán elementos adicionales en la interfaz. Al deshabilitarlo, estos elementos desaparecerán.';
$pia_lang['Maintenance_Tool_DevListCol_noti'] = 'Configurar la vista general del dispositivo';
$pia_lang['Maintenance_Tool_DevListCol_noti_text'] = '¿Desea guardar los cambios realizados? Este cambio afectará a todos los dispositivos que utilices para acceder a esta página.';
$pia_lang['Maintenance_Tool_setapikey_false'] = 'No hay conjunto de claves API';
$pia_lang['Maintenance_Tool_setapikey'] = 'Establecer la clave API';
$pia_lang['Maintenance_Tool_setapikey_text'] = 'Con la clave API es posible realizar consultas a la base de datos sin utilizar la página web. Este puede ser el caso si otro servicio debe acceder a los datos de esta base de datos. Si ya existe una clave API, ésta será sustituida.';
$pia_lang['Maintenance_Tool_setapikey_noti'] = 'Configuración de la clave API';
$pia_lang['Maintenance_Tool_setapikey_noti_text'] = '¿Desea sustituir una clave API existente por una nueva clave? Las claves existentes ya no se pueden utilizar.';
$pia_lang['Maintenance_Tool_ignorelist'] = 'Lista de ignorados';
$pia_lang['Maintenance_Tool_ignorelist_false'] = 'No hay lista de ignorados configurada';
$pia_lang['Maintenance_arpscantimer_empty'] = 'Período establecido';
$pia_lang['Maintenance_Tool_arpscansw'] = 'Activar scan (on/off)';
$pia_lang['Maintenance_Tool_arpscansw_text'] = 'Activa o desactiva el escaneo arp. Si no se ha establecido ningún periodo de tiempo para la desactivación, Pi.Alert se enciende de nuevo tras una pausa de 10 minutos con la siguiente exploración pendiente. Los escaneos que ya están en curso no se terminan.';
$pia_lang['Maintenance_Tool_arpscansw_noti'] = 'Activar arp-scan on or off';
$pia_lang['Maintenance_Tool_arpscansw_noti_text'] = 'Cuando el escaneo se ha apagado, permanece apagado hasta que se active nuevamente.';
$pia_lang['Maintenance_Tool_test_notification'] = 'Test Notifications';
$pia_lang['Maintenance_Tool_test_notification_text'] = 'Test reporting for all activated services.';
$pia_lang['Maintenance_Tool_test_notification_noti'] = '';
$pia_lang['Maintenance_Tool_test_notification_noti_text'] = '';
$pia_lang['Maintenance_Tool_del_alldev'] = 'Eliminar todos los dispositivos';
$pia_lang['Maintenance_Tool_del_alldev_text'] = 'Todos los dispositivos se eliminarán de la base de datos.';
$pia_lang['Maintenance_Tool_del_alldev_noti'] = 'Eliminar dispositivos';
$pia_lang['Maintenance_Tool_del_alldev_noti_text'] = '¿Estás seguro de que quieres eliminar todos los dispositivos?';
$pia_lang['Maintenance_Tool_del_unknowndev'] = 'Eliminar dispositivos (desconocidos)';
$pia_lang['Maintenance_Tool_del_unknowndev_text'] = 'Todos los dispositivos nombrados (desconocidos) se eliminarán de la base de datos.';
$pia_lang['Maintenance_Tool_del_unknowndev_noti'] = 'Eliminar dispositivos (desconocidos)';
$pia_lang['Maintenance_Tool_del_unknowndev_noti_text'] = '¿Estás seguro de que quieres eliminar todos los dispositivos (desconocidos)?';
$pia_lang['Maintenance_Tool_del_allevents'] = 'Eliminar todo (Restablecer historial)';
$pia_lang['Maintenance_Tool_del_allevents_text'] = 'Se eliminarán todos los eventos en la base de datos. En ese momento se restablecerá la presencia de todos los dispositivos. Esto puede conducir a sesiones no válidas. Esto significa que los dispositivos se muestran como "presentes", aunque están fuera de línea. Un escaneo mientras el dispositivo en cuestión está en línea resuelve el problema.';
$pia_lang['Maintenance_Tool_del_allevents_noti'] = 'Eliminar eventos';
$pia_lang['Maintenance_Tool_del_allevents_noti_text'] = '¿Estás seguro de que quieres eliminar todos los eventos? Esto restablece la presencia de todos los dispositivos.';
$pia_lang['Maintenance_Tool_del_Inactive_Hosts'] = 'Eliminar dispositivos inactivos';
$pia_lang['Maintenance_Tool_del_Inactive_Hosts_text'] = 'Se eliminan todos los dispositivos que han estado inactivos durante 30 días. Los eventos de estas unidades también se eliminan de la base de datos.';
$pia_lang['Maintenance_Tool_backup'] = 'Respaldar DB';
$pia_lang['Maintenance_Tool_backup_text'] = 'Las copias de seguridad de la base de datos se encuentran en el directorio de la base de datos como una Zip-Archive, nombrada con la fecha de creación. No hay un número máximo de copias de seguridad.';
$pia_lang['Maintenance_Tool_backup_noti'] = 'Respaldar DB';
$pia_lang['Maintenance_Tool_backup_noti_text'] = '¿Estás seguro de que quieres exactos la copia de seguridad de DB? Asegúrese de que ningún escaneo se esté ejecutando actualmente.';
$pia_lang['Maintenance_Tool_restore'] = 'Restaurar DB';
$pia_lang['Maintenance_Tool_restore_blocked'] = 'no disponible';
$pia_lang['Maintenance_Tool_restore_text'] = 'La última copia de seguridad se puede restaurar a través del botón, pero las copias de seguridad anteriores solo se pueden restaurar manualmente. Después de la restauración, realice una verificación de integridad en la base de datos por seguridad, en caso de que el DB estuviera actualmente en acceso de escritura cuando se creó la copia de seguridad.';
$pia_lang['Maintenance_Tool_restore_noti'] = 'Restaurar DB';
$pia_lang['Maintenance_Tool_restore_noti_text'] = '¿Estás seguro de que quieres hacer exactos la restauración de DB? Asegúrese de que ningún escaneo se esté ejecutando actualmente.';
$pia_lang['Maintenance_Tool_latestdb_download'] = 'Descargar último db backup';
$pia_lang['Maintenance_Tool_latestconf_download'] = 'Descargar pialert.conf actual';
$pia_lang['Maintenance_Tool_purgebackup'] = 'Purgar Respaldos';
$pia_lang['Maintenance_Tool_purgebackup_text'] = 'Todas las copias de seguridad serán eliminadas, excepto las 3 últimas.';
$pia_lang['Maintenance_Tool_purgebackup_noti'] = 'Purgar Respaldos';
$pia_lang['Maintenance_Tool_purgebackup_noti_text'] = '¿Está seguro de borrar todas las copias de seguridad excepto las 3 últimas?';
$pia_lang['Maintenance_Tool_del_ActHistory'] = 'Eliminar la actividad de la red';
$pia_lang['Maintenance_Tool_del_ActHistory_text'] = 'El gráfico de actividad de la red se resetea. Esto no afecta a los eventos.';
$pia_lang['Maintenance_Tool_del_ActHistory_noti'] = 'Borrar la actividad de la red';
$pia_lang['Maintenance_Tool_del_ActHistory_noti_text'] = '¿Está seguro de restablecer la actividad de la red?';
$pia_lang['Maintenance_Tool_loginenable'] = 'Login activado.';
$pia_lang['Maintenance_Tool_loginenable_text'] = 'Después de la activación, se le llevará automáticamente a la página de inicio de sesión. Si no has establecido una contraseña antes, "123456" es la contraseña por defecto.';
$pia_lang['Maintenance_Tool_loginenable_noti'] = 'Login activado.';
$pia_lang['Maintenance_Tool_loginenable_noti_text'] = '¿Estás seguro de que quieres activar el inicio de sesión?';
$pia_lang['Maintenance_Tool_logindisable'] = 'Login desactivado.';
$pia_lang['Maintenance_Tool_logindisable_text'] = 'El inicio de sesión se desactivará. Ahora, todos los usuarios tienen la posibilidad de acceder de nuevo a la página Pi.Alert.';
$pia_lang['Maintenance_Tool_logindisable_noti'] = 'Login desactivado.';
$pia_lang['Maintenance_Tool_logindisable_noti_text'] = '¿Estás seguro de que quieres desactivar el inicio de sesión?';
$pia_lang['Maintenance_ConfEditor_Start'] = 'Editar Pi.Alert Config';
$pia_lang['Maintenance_ConfEditor_Hint'] = 'Notas sobre el editor';
$pia_lang['Maintenance_ConfEditor_Backup'] = 'Crear copia de seguridad';
$pia_lang['Maintenance_ConfEditor_Restore'] = 'A la última versión';
$pia_lang['Maintenance_ConfEditor_Restore_noti'] = 'A la versión anterior';
$pia_lang['Maintenance_ConfEditor_Restore_noti_text'] = 'Se restaura la última versión del fichero de configuración. La "versión anterior" es la de la última copia de seguridad o la versión anterior al último guardado. Dependiendo de cuál sea más actual.';
$pia_lang['Maintenance_ConfEditor_Backup_info'] = 'Además del archivo "pialert-prev.bak", se crea otra copia de seguridad con la fecha y hora actuales. Esta copia de seguridad debe restaurarse manualmente si es necesario (cambiar el nombre a "pialert.conf"). Un archivo "pialert-prev.bak" existente siempre se sobrescribe.';
$pia_lang['Maintenance_ConfEditor_Restore_info'] = 'Esta función restaura el archivo de configuración desde el archivo "pialert-prev.bak". El archivo "pialert-prev.bak" se crea al guardar y crear una copia de seguridad.';
$pia_lang['Maintenance_ConfEditor_Save_info'] = 'El contenido del campo de texto con cualquier cambio se guarda en el archivo "pialert.conf". La configuración anterior se guarda como "pialert-prev.bak". Con cada guardado, el archivo "pialert-prev.bak" se sobrescribe una y otra vez con el archivo de configuración anterior.';
$pia_lang['Maintenance_Tool_ConfBackup'] = 'Crear Copia de Seguridad de la Configuración';
$pia_lang['Maintenance_Tool_ConfBackup_text'] = 'Además del archivo "pialert-prev.bak", se crea otra copia de seguridad con la fecha y hora actual. Esta copia de seguridad debe restaurarse manualmente si es necesario (renombrarla como "pialert.conf").';

/////////////////////////////////////////////////////////////////////////////
// Maintenance Page - Update by @TeroRERO 25jul2022 and leiweibau 29ago2022
/////////////////////////////////////////////////////////////////////////////

$pia_lang['BackDevices_Arpscan_disabled'] = 'Arp-Scan Desactivado';
$pia_lang['BackDevices_Arpscan_enabled'] = 'Arp-Scan Activado';
$pia_lang['BackDevices_setapikey'] = 'API-Key set';
$pia_lang['BackDevices_test_notification'] = 'Notification sent';
$pia_lang['BackDevices_darkmode_disabled'] = 'Darkmode Desactivado';
$pia_lang['BackDevices_darkmode_enabled'] = 'Darkmode Activado';
$pia_lang['BackDevices_webservicemon_disabled'] = 'Web Service Monitoring Disabled';
$pia_lang['BackDevices_webservicemon_enabled'] = 'Web Service Monitoring Enabled';
$pia_lang['BackDevices_MainScan_disabled'] = 'El Escaneo Principal está desactivado';
$pia_lang['BackDevices_MainScan_enabled'] = 'El Escaneo Principal está activado';
$pia_lang['BackDevices_onlinehistorygraph_disabled'] = 'Graph disabled.';
$pia_lang['BackDevices_onlinehistorygraph_enabled'] = 'Graph enabled.';
$pia_lang['BackDevices_Restore_CopError'] = 'La base de datos original no se pudo guardar.';
$pia_lang['BackDevices_Restore_okay'] = 'Restauración ejecutado con éxito.';
$pia_lang['BackDevices_Restore_Failed'] = 'La restauración falló. Restaurar la copia de seguridad manualmente.';
$pia_lang['BackDevices_Backup_WALError'] = 'The original database was not copied because transactions may be open.';
$pia_lang['BackDevices_Backup_IntegrityError'] = 'The copied database has not passed the integrity check.';
$pia_lang['BackDevices_Backup_CopError'] = 'La base de datos original no se pudo guardar.';
$pia_lang['BackDevices_Backup_okay'] = 'La copia de seguridad ejecutada con éxito con el nuevo archivo';
$pia_lang['BackDevices_Backup_Failed'] = 'La copia de seguridad se ejecutó parcialmente con éxito. El archivo no se puede crear o está vacío.';
$pia_lang['BackDevices_DBTools_DelDev_a'] = 'Dispositivo eliminado con éxito';
$pia_lang['BackDevices_DBTools_DelDev_b'] = 'Dispositivos eliminados con éxito';
$pia_lang['BackDevices_DBTools_DelEvents'] = 'Eventos eliminados con éxito';
$pia_lang['BackDevices_DBTools_DelEventsError'] = 'Error de eliminación de eventos';
$pia_lang['BackDevices_DBTools_DelDevError_a'] = 'Error de eliminación del dispositivo';
$pia_lang['BackDevices_DBTools_DelDevError_b'] = 'Error de eliminación de dispositivos';
$pia_lang['BackDevices_DBTools_UpdDev'] = 'Dispositivo actualizado con éxito';
$pia_lang['BackDevices_DBTools_UpdDevError'] = 'Error al actualizar el dispositivo';
$pia_lang['BackDevices_DBTools_Purge'] = 'Las copias de seguridad más antiguas fueron eliminadas';
$pia_lang['BackDevices_DBTools_DelActHistory'] = 'Network aktivity reset successful';
$pia_lang['BackDevices_DBTools_DelActHistoryError'] = 'Network aktivity reset not successful';
$pia_lang['BackDevices_DBTools_DelInactHosts'] = 'Se han eliminado los hosts inactivos.';
$pia_lang['BackDevices_DBTools_DelInactHostsError'] = 'Se ha producido un error al intentar eliminar hosts inactivos.';
$pia_lang['BackDevices_Login_disabled'] = 'Login desactivado.';
$pia_lang['BackDevices_Login_enabled'] = 'Login activado.';
$pia_lang['BackDevices_Theme_set'] = 'Theme applied';
$pia_lang['BackDevices_Theme_notset'] = 'Theme not applied';
$pia_lang['BackDevices_Theme_invalid'] = 'Selection invalid';
$pia_lang['BackDevices_Language_set'] = 'Theme applied';
$pia_lang['BackDevices_Language_notset'] = 'Theme not applied';
$pia_lang['BackDevices_Language_invalid'] = 'Selection invalid';
$pia_lang['BackDevices_DevListCol_noti_text'] = 'Tabelleneinstellung wird gespeichert.';
$pia_lang['BackDevices_ConfEditor_CopError'] = 'No es posible guardar la configuración.';
$pia_lang['BackDevices_ConfEditor_CopOkay'] = 'La copia de seguridad de la configuración ha finalizado.';
$pia_lang['BackDevices_ConfEditor_RestoreError'] = 'The last version of the configuration could not be restored.';
$pia_lang['BackDevices_ConfEditor_RestoreOkay'] = 'The last version of the configuration has been restored.';
$pia_lang['BackDevices_Report_Delete'] = ' Notificación(es) eliminada(s).';

//////////////////////////////////////////////////////////////////
// Network Page - Update by @TeroRERO 01ago2022
//////////////////////////////////////////////////////////////////

$pia_lang['Network_Title'] = 'Descripción general de la red';
$pia_lang['Network_ManageDevices'] = 'Administrar dispositivos';
$pia_lang['Network_ManageAdd_Name'] = 'Nombre del dispositivo';
$pia_lang['Network_ManageAdd_Name_text'] = 'Nombre sin caracteres especiales';
$pia_lang['Network_ManageAdd_Type'] = 'Tipo de dispositivo';
$pia_lang['Network_ManageAdd_Type_text'] = '-- Seleccionar tipo --';
$pia_lang['Network_ManageAdd_Port'] = 'Recuento de puertos';
$pia_lang['Network_ManageAdd_Port_text'] = 'dejar en blanco para WiFi y Powerline';
$pia_lang['Network_ManageAdd_Submit'] = 'Añadir dispositivo';
$pia_lang['Network_ManageEdit_ID'] = 'Dispositivo para actualizar';
$pia_lang['Network_ManageEdit_ID_text'] = '-- Seleccione el dispositivo para editar --';
$pia_lang['Network_ManageEdit_Name'] = 'Nuevo nombre del dispositivo';
$pia_lang['Network_ManageEdit_Name_text'] = 'Nombre sin caracteres especiales';
$pia_lang['Network_ManageEdit_Type'] = 'Nuevo tipo de dispositivo';
$pia_lang['Network_ManageEdit_Type_text'] = '-- Seleccione tipo --';
$pia_lang['Network_ManageEdit_Port'] = ' Nuevo recuento de puertos';
$pia_lang['Network_ManageEdit_Port_text'] = 'Dejar en blanco para WiFi y Powerline';
$pia_lang['Network_ManageEdit_Downlink'] = 'manual Port-Configuration (Target-MAC,locale Port)';
$pia_lang['Network_ManageEdit_Downlink_text'] = '0a:1b:3c:4d:5e:6f,16;Target-MAC 2,Port 2;';
$pia_lang['Network_ManageEdit_Submit'] = 'Guardar los cambios';
$pia_lang['Network_ManageDel_Name'] = 'Dispositivo para eliminar';
$pia_lang['Network_ManageDel_Name_text'] = '-- Seleccione el dispositivo --';
$pia_lang['Network_ManageDel_Submit'] = 'Eliminar';
$pia_lang['Network_Table_State'] = 'Estado';
$pia_lang['Network_Table_Hostname'] = 'Nombre de host';
$pia_lang['Network_Table_IP'] = 'Dirección IP';
$pia_lang['Network_UnassignedDevices'] = 'Unassigned devices';
$pia_lang['NetworkSettings_Title'] = 'Configuración: Resumen de la red';
$pia_lang['Network_ManageDevices_Intro'] = 'Esta sección se utiliza para crear dispositivos transparentes/sin IP (no gestionados), como concentradores o interruptores, así como dispositivos activos como enrutadores, interruptores gestionados o puntos de acceso que influyen en la estructura de la red. Los dispositivos ya detectados por Pi.Alert deben crearse nuevamente aquí para su visualización. La edición o eliminación de dispositivos ya detectados por Pi.Alert es independiente de la lista "<span class="text-maroon help_faq_code">' . $pia_lang['Navigation_Devices'] . '</span>" y solo tiene relevancia para la página "<span class="text-maroon help_faq_code">' . $pia_lang['Navigation_Network'] . '</span>".';
$pia_lang['Network_Unmanaged_Devices'] = 'Gestionar dispositivos no escaneables';
$pia_lang['Network_Unmanaged_Devices_Intro'] = 'En este lugar, se pueden crear dispositivos finales que ocupan puertos o conexiones en interruptores o enrutadores, pero que no tienen funcionalidad de red por sí mismos. También se pueden considerar dispositivos que no se pueden detectar pero que se deben mostrar para tener una visión general. Los dispositivos creados aquí solo aparecen en la página "<span class="text-maroon help_faq_code">' . $pia_lang['Navigation_Network'] . '</span>".';
$pia_lang['Network_Unmanaged_Devices_Connected'] = 'Conectado a';
$pia_lang['Network_Unmanaged_Devices_Connected_text'] = 'Seleccionar dispositivo';
$pia_lang['Network_Unmanaged_Devices_Port'] = 'En el puerto';
$pia_lang['Network_Unmanaged_Devices_Port_text'] = 'En el número de puerto del dispositivo seleccionado';

//////////////////////////////////////////////////////////////////
// Help Page - Update by @TeroRERO 07ago2022
//////////////////////////////////////////////////////////////////

$pia_lang['HelpFAQ_Title'] = 'Ayuda / FAQ';
$pia_lang['HelpFAQ_Cat_General'] = 'General';
$pia_lang['HelpFAQ_Cat_Detail'] = 'Detalles';
$pia_lang['HelpFAQ_Cat_General_100_head'] = 'El reloj en la parte superior derecha y el tiempo de los eventos/presencia no son correctos (diferencia de tiempo).';
$pia_lang['HelpFAQ_Cat_General_100_text_a'] = 'En su PC, la siguiente zona horaria está configurada para el entorno PHP:';
$pia_lang['HelpFAQ_Cat_General_100_text_b'] = 'Si esta no es la zona horaria en la que se encuentra, debe cambiar la zona horaria en el archivo de configuración de PHP. Puedes encontrarlo en este directorio:';
$pia_lang['HelpFAQ_Cat_General_100_text_c'] = 'Busque en este archivo la entrada "date.timezone", elimine el ";" inicial si es necesario e introduzca la zona horaria deseada. Puede encontrar una lista con las zonas horarias compatibles aquí (<a href="https://www.php.net/manual/en/timezones.php" target="blank">Link</a>)';
$pia_lang['HelpFAQ_Cat_General_101_head'] = 'Mi red parece ralentizarse, el streaming se "congela".';
$pia_lang['HelpFAQ_Cat_General_101_text'] = 'Es muy posible que los dispositivos de baja potencia alcancen sus límites de rendimiento con la forma en que Pi.Alert detecta nuevos dispositivos en la red. Esto se amplifica aún más,
											si estos dispositivos se comunican con la red a través de WLAN. Las soluciones aquí serían cambiar a una conexión por cable si es posible o, si el dispositivo sólo se va a utilizar durante un período de tiempo limitado, utilizar el arp scan.
											pausar el arp scan en la página de mantenimiento.';
$pia_lang['HelpFAQ_Cat_General_102_head'] = 'Me aparece el mensaje de que la base de datos es de sólo de lectura.';
$pia_lang['HelpFAQ_Cat_General_102_text'] = 'Compruebe en el directorio Pi.Alert si la carpeta de la base de datos (db) tiene asignados los permisos correctos:<br>
              								 <span class="text-maroon help_faq_code">drwxrwx---  2 (nombre de usuario) www-data</span><br>
              								 Si el permiso no es correcto, puede establecerlo de nuevo con los siguientes comandos en la terminal o la consola:<br>
              								 <div class="help_faq_code" style="padding-left: 10px; margin-bottom: 10px;">
              								 sudo chgrp -R www-data ~/pialert/db<br>
              								 sudo chown [Username]:www-data ~/pialert/db/pialert.db<br>
                							 chmod -R 770 ~/pialert/db
              								 </div>
              								 También puedes realizar estos pasos utilizando <span class="text-maroon help_faq_code">./pialert-cli set_permissions</span> en el directorio <span class="text-maroon help_faq_code">~/pialert/back</span>. Si la base de datos sigue estando en modo de solo lectura después de esto,
              								 intenta reinstalar o restaurar una copia de seguridad de la base de datos a través de la página de mantenimiento. Por favor, asegúrate de verificar y ajustar los permisos correspondientes.';
$pia_lang['HelpFAQ_Cat_General_103_head'] = 'La página de inicio de sesión no aparece, incluso después de cambiar la contraseña.';
$pia_lang['HelpFAQ_Cat_General_103_text'] = 'Además de la contraseña, el archivo de configuración debe contener <span class="text-maroon help_faq_code">~/pialert/config/pialert.conf</span>
              								 además el parámetro <span class="text-maroon help_faq_code">PIALERT_WEB_PROTECTION</span> debe ajustarse a <span class="text-maroon help_faq_code">True</span>.';
$pia_lang['HelpFAQ_Cat_General_104_head'] = 'Notes on migrating from pucherot to this fork.';
$pia_lang['HelpFAQ_Cat_General_104_text'] = 'The database in this fork has been extended by some fields. To take over the database from the original Pi.Alert (pucherot), an update function is available via the "pialert-cli" in the directory <span class="text-maroon help_faq_code">~/pialert/back</span>.
											 The command is then <span class="text-maroon help_faq_code">./pialert-cli update_db</span>';
$pia_lang['HelpFAQ_Cat_General_105_head'] = 'pialert-cli';
$pia_lang['HelpFAQ_Cat_General_105_text'] = 'The command line tool <span class="text-maroon help_faq_code">pialert-cli</span> is located in the directory <span class="text-maroon help_faq_code">~/pialert/back</span> and offers the possibility to make settings to Pi.Alert
                                             without web page or change to the configuration file. With the command <span class="text-maroon help_faq_code">./pialert-cli help</span> a list with the supported options can be called.
											 <table class="help_table_gen">
											    <tr><td class="help_table_gen_a">set_login</td>
												    <td class="help_table_gen_b">- Establece el parámetro PIALERT_WEB_PROTECTION en el archivo de configuración a TRUE.<br>
												        - Si el parámetro no está presente, se creará. Además, se establecerá la contraseña predeterminada "123456".</td></tr>
												<tr><td class="help_table_gen_a">unset_login</td>
												    <td class="help_table_gen_b">- Establece el parámetro PIALERT_WEB_PROTECTION en el archivo de configuración a FALSE.<br>
												        - Si el parámetro no está presente, se creará. Además, se establecerá la contraseña predeterminada "123456".</td></tr>
												<tr><td class="help_table_gen_a">set_password &lt;password&gt;</td>
												    <td class="help_table_gen_b">- Establece la nueva contraseña como un valor hash.<br>
												        - Si el parámetro PIALERT_WEB_PROTECTION no existe aún, se creará y se establecerá en "TRUE" (inicio de sesión habilitado).</td></tr>
												<tr><td class="help_table_gen_a">set_autopassword</td>
												    <td class="help_table_gen_b">- Establece una nueva contraseña aleatoria como un valor hash y la muestra en texto sin formato en la consola.<br>
												        - Si el parámetro PIALERT_WEB_PROTECTION no existe aún, se creará y se establecerá en "TRUE" (inicio de sesión habilitado).</td></tr>
												<tr><td class="help_table_gen_a">disable_scan &lt;MIN&gt;</td>
												    <td class="help_table_gen_b">- Detiene todas las exploraciones activas.<br>
												        - Impide que se inicien nuevas exploraciones.</td></tr>
												<tr><td class="help_table_gen_a">enable_scan</td>
												    <td class="help_table_gen_b">- Permite el inicio de nuevas exploraciones nuevamente.</td></tr>
												<tr><td class="help_table_gen_a">disable_mainscan</td>
												    <td class="help_table_gen_b">- Desactiva el método principal de escaneo para Pi.Alert (escaneo ARP)</td></tr>
												<tr><td class="help_table_gen_a">enable_mainscan</td>
												    <td class="help_table_gen_b">- Activa el método principal de escaneo para Pi.Alert (escaneo ARP)</td></tr>
												<tr><td class="help_table_gen_a">enable_service_mon</td>
												    <td class="help_table_gen_b">- Habilita la supervisión de servicios web.</td></tr>
												<tr><td class="help_table_gen_a">disable_service_mon</td>
												    <td class="help_table_gen_b">- Deshabilita la supervisión de servicios web.</td></tr>
											    <tr><td class="help_table_gen_a">enable_icmp_mon</td>
											        <td class="help_table_gen_b">- Enable ICMP Monitoring (ping)<br>&nbsp;</td></tr>
											    <tr><td class="help_table_gen_a">disable_icmp_mon</td>
											        <td class="help_table_gen_b">- Disable ICMP Monitoring (ping)<br>&nbsp;</td></tr>
												<tr><td class="help_table_gen_a">update_db</td>
												    <td class="help_table_gen_b">- El script intenta hacer que la base de datos sea compatible con esta bifurcación.</td></tr>
												<tr><td class="help_table_gen_a">set_apikey</td>
												    <td class="help_table_gen_b">- Con la clave API es posible hacer consultas a la base de datos sin utilizar la página web. Si ya existe una clave API, se reemplazará.</td></tr>
												<tr><td class="help_table_gen_a">set_permissions</td>
												    <td class="help_table_gen_b">- Corrige los permisos de archivo de la base de datos.</td></tr>
												<tr><td class="help_table_gen_a">reporting_test</td>
												    <td class="help_table_gen_b">- Prueba de informes para todos los servicios activados.</td></tr>
											    <tr><td class="help_table_gen_a">set_sudoers</td>
											        <td class="help_table_gen_b">- Create sudoer file for www-data and Pi.Alert user</td></tr>
											    <tr><td class="help_table_gen_a">unset_sudoers</td>
											        <td class="help_table_gen_b">- Delete sudoer file for www-data and Pi.Alert user</td></tr>
											</table>';
$pia_lang['HelpFAQ_Cat_General_106_head'] = '<span class="text-maroon help_faq_code">Algunos componentes de Pi.Alert requieren permisos "sudo"</span>';
$pia_lang['HelpFAQ_Cat_General_106_text'] = 'Ciertas funciones de Pi.Alert, como el envío de mensajes de prueba, la detección de servidores DHCP extranjeros o la identificación de dispositivos mediante arp-scan,
											 requieren permisos "sudo". Es necesario realizar un ajuste de configuración para esto. Para hacerlo, en el directorio <span class="text-maroon help_faq_code">~/pialert/back</span>,
											 ejecuta el comando <span class="text-maroon help_faq_code">sudo ./pialert-cli set_sudoers</span>.';
$pia_lang['HelpFAQ_Cat_General_107_head'] = 'pialert.conf';
$pia_lang['HelpFAQ_Cat_General_107_text'] = 'The file <span class="text-maroon help_faq_code">pialert.conf</span> is located in the directory <span class="text-maroon help_faq_code">~/pialert/config</span>.
											 In this configuration file many functions of Pi.Alert can be set according to the personal wishes. Since the possibilities are various, I would like to give a
											 short explanation to the individual points.
											 <table class="help_table_gen">
											    <tr><td class="help_table_gen_section" colspan="2">General Settings</td></tr>
											    <tr><td class="help_table_gen_a">PIALERT_PATH</td>
												    <td class="help_table_gen_b">Esta variable se establece durante la instalación y no debe modificarse.</td></tr>
												<tr><td class="help_table_gen_a">DB_PATH</td>
												    <td class="help_table_gen_b">Esta variable se establece durante la instalación y no debe modificarse.</td></tr>
												<tr><td class="help_table_gen_a">LOG_PATH</td>
												    <td class="help_table_gen_b">Esta variable se establece durante la instalación y no debe modificarse.</td></tr>
												<tr><td class="help_table_gen_a">PRINT_LOG</td>
												    <td class="help_table_gen_b">Si esta entrada se establece en <span class="text-maroon help_faq_code">True</span>, se agregan marcas de tiempo adicionales para las subfunciones individuales en el registro de escaneo. De forma predeterminada, esta entrada se establece en <span class="text-maroon help_faq_code">False</span>.</td></tr>
												<tr><td class="help_table_gen_a">VENDORS_DB</td>
												    <td class="help_table_gen_b">Esta variable se establece durante la instalación y no debe modificarse.</td></tr>
												<tr><td class="help_table_gen_a">PIALERT_APIKEY</td>
												    <td class="help_table_gen_b">Con la clave de API, es posible realizar consultas a la base de datos sin utilizar la página web. La clave de API es una cadena aleatoria que se puede establecer a través de la configuración o mediante <span class="text-maroon help_faq_code">pialert-cli</span>.</td></tr>
												<tr><td class="help_table_gen_a">PIALERT_WEB_PROTECTION</td>
												    <td class="help_table_gen_b">Activa o desactiva la protección con contraseña de la interfaz web de Pi.Alert.</td></tr>
												<tr><td class="help_table_gen_a">PIALERT_WEB_PASSWORD</td>
												    <td class="help_table_gen_b">Este campo contiene la contraseña cifrada para la interfaz web. La contraseña no se puede ingresar aquí en texto plano, sino que debe establecerse con <span class="text-maroon help_faq_code">pialert-cli</span>.</td></tr>
											</table>
											<table class="help_table_gen">
											    <tr><td class="help_table_gen_section" colspan="2">Other Modules</td></tr>
											    <tr><td class="help_table_gen_a">SCAN_WEBSERVICES</td>
												    <td class="help_table_gen_b">Aquí se puede activar (<span class="text-maroon help_faq_code">True</span>) o desactivar (<span class="text-maroon help_faq_code">False</span>) la función de monitoreo de servicios web.</td></tr>
											    <tr><td class="help_table_gen_a">ICMPSCAN_ACTIVE</td>
											        <td class="help_table_gen_b">ICMP Monitoring on/off</td></tr>
											</table>
											<table class="help_table_gen">
											    <tr><td class="help_table_gen_section" colspan="2">Special Protocol Scanning</td></tr>
											    <tr><td class="help_table_gen_a">SCAN_ROGUE_DHCP</td>
												    <td class="help_table_gen_b">Activa la búsqueda de servidores DHCP externos, también conocidos como "rogue". Esta función se utiliza para detectar si hay un servidor DHCP externo en la red que podría tomar el control de la gestión de IP.</td></tr>
												<tr><td class="help_table_gen_a">DHCP_SERVER_ADDRESS</td>
												    <td class="help_table_gen_b">Aquí se almacena la dirección IP del servidor DHCP conocido.</td></tr>
											</table>
											<table class="help_table_gen">
											    <tr><td class="help_table_gen_section" colspan="2">Mail-Account Settings</td></tr>
											    <tr><td class="help_table_gen_a">SMTP_SERVER</td>
												    <td class="help_table_gen_b">Dirección del servidor de correo electrónico (por ejemplo, smtp.gmail.com)</td></tr>
												<tr><td class="help_table_gen_a">SMTP_PORT</td>
												    <td class="help_table_gen_b">El puerto del servidor SMTP. El puerto puede variar según la configuración del servidor.</td></tr>
												<tr><td class="help_table_gen_a">SMTP_USER</td>
												    <td class="help_table_gen_b">Nombre de usuario</td></tr>
												<tr><td class="help_table_gen_a">SMTP_PASS</td>
												    <td class="help_table_gen_b">Contraseña</td></tr>
												<tr><td class="help_table_gen_a">SMTP_SKIP_TLS</td>
												    <td class="help_table_gen_b">Si esta entrada se establece en <span class="text-maroon help_faq_code">True</span>, se habilita el cifrado de transporte del correo electrónico. Si el servidor no admite esto, la entrada debe establecerse en <span class="text-maroon help_faq_code">False</span>.</td></tr>
												<tr><td class="help_table_gen_a">SMTP_SKIP_LOGIN</td>
												    <td class="help_table_gen_b">Hay servidores SMTP que no requieren inicio de sesión. En tal caso, este valor se puede establecer en <span class="text-maroon help_faq_code">True</span>.</td></tr>
											</table>
											<table class="help_table_gen">
											    <tr><td class="help_table_gen_section" colspan="2">WebGUI Reporting</td></tr>
												<tr><td class="help_table_gen_a">REPORT_WEBGUI</td>
												    <td class="help_table_gen_b">Activa/desactiva las notificaciones sobre cambios en la red en la interfaz web.</td></tr>
												<tr><td class="help_table_gen_a">REPORT_WEBGUI_WEBMON</td>
												    <td class="help_table_gen_b">Activa/desactiva las notificaciones sobre cambios en los servicios web monitoreados en la interfaz web.</td></tr>
											</table>
											<table class="help_table_gen">
											    <tr><td class="help_table_gen_section" colspan="2">Mail Reporting</td></tr>
												<tr><td class="help_table_gen_a">REPORT_MAIL</td>
												    <td class="help_table_gen_b">Activa/desactiva las notificaciones sobre cambios en la red mediante correo electrónico.</td></tr>
												<tr><td class="help_table_gen_a">REPORT_MAIL_WEBMON</td>
												    <td class="help_table_gen_b">Activa/desactiva la notificación de cambios en los servicios web monitoreados mediante correo electrónico.</td></tr>
												<tr><td class="help_table_gen_a">REPORT_FROM</td>
												    <td class="help_table_gen_b">Nombre o identificador del remitente.</td></tr>
												<tr><td class="help_table_gen_a">REPORT_TO</td>
												    <td class="help_table_gen_b">Dirección de correo electrónico a la cual se debe enviar la notificación.</td></tr>
												<tr><td class="help_table_gen_a">REPORT_DEVICE_URL</td>
												    <td class="help_table_gen_b">URL de la instalación de Pi.Alert para crear un enlace clickable en el correo electrónico hacia el dispositivo detectado.</td></tr>
												<tr><td class="help_table_gen_a">REPORT_DASHBOARD_URL</td>
												    <td class="help_table_gen_b">URL de la instalación de Pi.Alert, para poder crear un enlace clickable en el correo electrónico.</td></tr>
											</table>
											<table class="help_table_gen">
											    <tr><td class="help_table_gen_section" colspan="2">Pushsafer</td></tr>
											    <tr><td class="help_table_gen_a">REPORT_PUSHSAFER</td>
												    <td class="help_table_gen_b">Permite habilitar/deshabilitar notificaciones sobre cambios en la red a través de Pushsafer.</td></tr>
												<tr><td class="help_table_gen_a">REPORT_PUSHSAFER_WEBMON</td>
												    <td class="help_table_gen_b">Permite habilitar/deshabilitar notificaciones sobre cambios en los servicios web monitoreados a través de Pushsafer.</td></tr>
												<tr><td class="help_table_gen_a">PUSHSAFER_TOKEN</td>
												    <td class="help_table_gen_b">Esta es la clave privada que se puede ver en la página de Pushsafer.</td></tr>
												<tr><td class="help_table_gen_a">PUSHSAFER_DEVICE</td>
												    <td class="help_table_gen_b">El ID del dispositivo al cual se enviará el mensaje. &lsquo;<span class="text-maroon help_faq_code">a</span>&rsquo; significa que el mensaje se enviará a todos los dispositivos configurados y consumirá un número correspondiente de llamadas API.</td></tr>
											</table>
											<table class="help_table_gen">
											    <tr><td class="help_table_gen_section" colspan="2">Pushover</td></tr>
												<tr><td class="help_table_gen_a">REPORT_PUSHOVER</td>
												    <td class="help_table_gen_b">Permite habilitar/deshabilitar notificaciones sobre cambios en la red a través de Pushover.</td></tr>
												<tr><td class="help_table_gen_a">REPORT_PUSHOVER_WEBMON</td>
												    <td class="help_table_gen_b">Permite habilitar/deshabilitar notificaciones sobre cambios en los servicios web monitoreados a través de Pushover.</td></tr>
												<tr><td class="help_table_gen_a">PUSHOVER_TOKEN</td>
												    <td class="help_table_gen_b">También conocido como "APP TOKEN" o "API TOKEN". Este token se puede obtener en la página de Pushover.</td></tr>
												<tr><td class="help_table_gen_a">PUSHOVER_USER</td>
												    <td class="help_table_gen_b">También conocido como "USER KEY". Esta clave se muestra justo después de iniciar sesión en la página de inicio.</td></tr>
											</table>
											<table class="help_table_gen">
					    						<tr><td class="help_table_gen_section" colspan="2">NTFY</td></tr>
												<tr><td class="help_table_gen_a">REPORT_NTFY</td>
												    <td class="help_table_gen_b">Permite habilitar/deshabilitar notificaciones sobre cambios en la red a través de NTFY.</td></tr>
												<tr><td class="help_table_gen_a">REPORT_NTFY_WEBMON</td>
												    <td class="help_table_gen_b">Permite habilitar/deshabilitar notificaciones sobre cambios en los servicios web monitoreados a través de NTFY.</td></tr>
												<tr><td class="help_table_gen_a">NTFY_HOST</td>
												    <td class="help_table_gen_b">El nombre de host o la dirección IP del servidor NTFY.</td></tr>
												<tr><td class="help_table_gen_a">NTFY_TOPIC</td>
												    <td class="help_table_gen_b">El tema o asunto de las notificaciones enviadas a través de NTFY.</td></tr>
												<tr><td class="help_table_gen_a">NTFY_USER</td>
												    <td class="help_table_gen_b">El nombre de usuario utilizado para autenticarse en el servidor NTFY.</td></tr>
												<tr><td class="help_table_gen_a">NTFY_PASSWORD</td>
												    <td class="help_table_gen_b">La contraseña utilizada para autenticarse en el servidor NTFY.</td></tr>
												<tr><td class="help_table_gen_a">NTFY_PRIORITY</td>
												    <td class="help_table_gen_b">La prioridad de las notificaciones enviadas a través de NTFY.</td></tr>
											</table>
											<table class="help_table_gen">
											    <tr><td class="help_table_gen_section" colspan="2">Shoutrrr</td></tr>
												<tr><td class="help_table_gen_a">SHOUTRRR_BINARY</td>
												    <td class="help_table_gen_b">Aquí debes configurar qué archivo binario de Shoutrrr se debe utilizar. Esto depende del hardware en el que se haya instalado Pi.Alert.</td></tr>
											</table>
											<table class="help_table_gen">
											    <tr><td class="help_table_gen_section" colspan="2">Telegram via Shoutrrr</td></tr>
												<tr><td class="help_table_gen_a">REPORT_TELEGRAM</td>
												    <td class="help_table_gen_b">Habilita/deshabilita las notificaciones sobre cambios en la red a través de Telegram.</td></tr>
												<tr><td class="help_table_gen_a">REPORT_TELEGRAM_WEBMON</td>
												    <td class="help_table_gen_b">Habilita/deshabilita las notificaciones sobre cambios en los servicios web monitoreados a través de Telegram.</td></tr>
												<tr><td class="help_table_gen_a">TELEGRAM_BOT_TOKEN_URL</td>
												    <td class="help_table_gen_b">    </td></tr>
											</table>
											<table class="help_table_gen">
											    <tr><td class="help_table_gen_section" colspan="2">DynDNS and IP</td></tr>
											    <tr><td class="help_table_gen_a">QUERY_MYIP_SERVER</td>
											        <td class="help_table_gen_b">    </td></tr>
											    <tr><td class="help_table_gen_a">DDNS_ACTIVE</td>
    												<td class="help_table_gen_b">Habilita/deshabilita el servicio DDNS configurado en Pi.Alert. DDNS, también conocido como DynDNS, te permite actualizar un nombre de dominio con una dirección IP que cambia regularmente. Este servicio es ofrecido por varios proveedores de servicios.</td></tr>
											    <tr><td class="help_table_gen_a">DDNS_DOMAIN</td>
											        <td class="help_table_gen_b">    </td></tr>
											    <tr><td class="help_table_gen_a">DDNS_USER</td>
											        <td class="help_table_gen_b">    </td></tr>
											    <tr><td class="help_table_gen_a">DDNS_PASSWORD</td>
											        <td class="help_table_gen_b">    </td></tr>
											    <tr><td class="help_table_gen_a">DDNS_UPDATE_URL</td>
											        <td class="help_table_gen_b">    </td></tr>
											</table>
											<table class="help_table_gen">
											    <tr><td class="help_table_gen_section" colspan="2">Arp-scan Options & Samples</td></tr>
											        <td class="help_table_gen_b">
											            <span class="text-maroon help_faq_code">[&apos;MAC-Address 1&apos;, &apos;MAC-Address 2&apos;]</span><br>
											            Estas direcciones MAC (guardadas con letras minúsculas) se filtran de los resultados del escaneo.</td></tr>
											    <tr><td class="help_table_gen_a">SCAN_SUBNETS</td>
												    <td class="help_table_gen_b">
												        &lsquo;<span class="text-maroon help_faq_code">--localnet</span>&rsquo;<br>
												        Normalmente esta opción ya está configurada correctamente. Esta configuración se selecciona cuando Pi.Alert se instala en un dispositivo con una tarjeta de red y no se configuran otras redes.<br><br>
												        &lsquo;<span class="text-maroon help_faq_code">--localnet --interface=eth0</span>&rsquo;<br>
												        Esta configuración se selecciona si Pi.Alert se instala en un sistema con al menos 2 tarjetas de red y una red configurada. Sin embargo, la designación de la interfaz puede variar y debe adaptarse a las condiciones del sistema.<br><br>
												        <span class="text-maroon help_faq_code">[&apos;192.168.1.0/24 --interface=eth0&apos;,&apos;192.168.2.0/24 --interface=eth1&apos;]</span><br>
												        La última configuración es necesaria si se van a monitorear varias redes. Para cada red que se va a monitorear, se debe configurar una tarjeta de red correspondiente. Esto es necesario porque el "arp-scan" utilizado no está enrutado, es decir, solo funciona dentro de su propio subred. Cada interfaz se ingresa aquí con la red correspondiente. La designación de la interfaz debe adaptarse a las condiciones del sistema.
												    </td></tr>
											</table>
											<table class="help_table_gen">
											    <tr><td class="help_table_gen_section" colspan="2">Opciones de Monitoreo ICMP</td></tr>
											    <tr><td class="help_table_gen_a">ICMP_ONLINE_TEST</td>
											        <td class="help_table_gen_b">Número de intentos para determinar si un dispositivo está en línea (Valor predeterminado 1).</td></tr>
											    <tr><td class="help_table_gen_a">ICMP_GET_AVG_RTT</td>
											        <td class="help_table_gen_b">Número de "ping&apos;s" para calcular el tiempo de respuesta promedio (Valor predeterminado 2).</td></tr>
											</table>
											<table class="help_table_gen">
											    <tr><td class="help_table_gen_section" colspan="2">Pi-hole Configuration</td></tr>
												<tr><td class="help_table_gen_a">PIHOLE_ACTIVE</td>
												    <td class="help_table_gen_b">Esta variable se configura durante la instalación.</td></tr>
												<tr><td class="help_table_gen_a">PIHOLE_DB</td>
												    <td class="help_table_gen_b">Esta variable se configura durante la instalación y no debe modificarse.</td></tr>
												<tr><td class="help_table_gen_a">DHCP_ACTIVE</td>
												    <td class="help_table_gen_b">Esta variable se configura durante la instalación.</td></tr>
												<tr><td class="help_table_gen_a">DHCP_LEASES</td>
												    <td class="help_table_gen_b">Esta variable se configura durante la instalación y no debe modificarse.</td></tr>
											</table>
											<table class="help_table_gen">
					    						<tr><td class="help_table_gen_section" colspan="2">Fritzbox Configuration</td></tr>
												<tr><td class="help_table_gen_a">FRITZBOX_ACTIVE</td>
												    <td class="help_table_gen_b">Si se utiliza un Fritzbox en la red, se puede utilizar como fuente de datos. Esto se puede activar o desactivar en este punto.</td></tr>
												<tr><td class="help_table_gen_a">FRITZBOX_IP</td>
												    <td class="help_table_gen_b">Dirección IP del Fritzbox.</td></tr>
												<tr><td class="help_table_gen_a">FRITZBOX_USER</td>
												    <td class="help_table_gen_b">Nombre de usuario<br>Esto asume que el Fritzbox está configurado para un inicio de sesión con nombre de usuario y contraseña, en lugar de solo contraseña. No se admite el inicio de sesión solo con contraseña.</td></tr>
												<tr><td class="help_table_gen_a">FRITZBOX_PASS</td>
												    <td class="help_table_gen_b">Contraseña</td></tr>
											</table>
											<table class="help_table_gen">
											    <tr><td class="help_table_gen_section" colspan="2">Configuración de Mikrotik</td></tr>
											    <tr><td class="help_table_gen_a">MIKROTIK_ACTIVE</td>
											        <td class="help_table_gen_b">Si se utiliza un router Mikrotik en la red, se puede utilizar como fuente de datos. Esto se puede habilitar o deshabilitar en este punto.</td></tr>
											    <tr><td class="help_table_gen_a">MIKROTIK_IP</td>
											        <td class="help_table_gen_b">Dirección IP del router Mikrotik.</td></tr>
											    <tr><td class="help_table_gen_a">MIKROTIK_USER</td>
											        <td class="help_table_gen_b">Nombre de usuario</td></tr>
											    <tr><td class="help_table_gen_a">MIKROTIK_PASS</td>
											        <td class="help_table_gen_b">Contraseña</td></tr>
											</table>
											<table class="help_table_gen">
											    <tr><td class="help_table_gen_section" colspan="2">Configuración de UniFi</td></tr>
											    <tr><td class="help_table_gen_a">UNIFI_ACTIVE</td>
											        <td class="help_table_gen_b">Si se utiliza un sistema UniFi en la red, se puede utilizar como fuente de datos. Esto se puede habilitar o deshabilitar en este punto.</td></tr>
											    <tr><td class="help_table_gen_a">UNIFI_IP</td>
											        <td class="help_table_gen_b">Dirección IP del sistema Unifi.</td></tr>
											    <tr><td class="help_table_gen_a">UNIFI_USER</td>
											        <td class="help_table_gen_b">Nombre de usuario</td></tr>
											    <tr><td class="help_table_gen_a">UNIFI_PASS</td>
											        <td class="help_table_gen_b">Contraseña</td></tr>
											</table>
											<table class="help_table_gen">
											    <tr><td class="help_table_gen_section" colspan="2">Maintenance Tasks Cron</td></tr>
												<tr><td class="help_table_gen_a">DAYS_TO_KEEP_ONLINEHISTORY</td>
												    <td class="help_table_gen_b">Número de días durante los cuales se almacenará el historial en línea (gráfico de actividad) en la base de datos. Un día genera 288 registros de este tipo.</td></tr>
												<tr><td class="help_table_gen_a">DAYS_TO_KEEP_EVENTS</td>
												    <td class="help_table_gen_b">Número de días durante los cuales se almacenarán los eventos de los dispositivos individuales.</td></tr>
											</table>';
$pia_lang['HelpFAQ_Cat_Device_200_head'] = 'Tengo dispositivos en mi lista que no conozco. Después de borrarlos, siempre vuelven a aparecer.';
$pia_lang['HelpFAQ_Cat_Device_200_text'] = 'Si utiliza Pi-hole, tenga en cuenta que Pi.Alert recupera información de Pi-hole. Ponga en pausa Pi.Alert, vaya a la página de configuración de Pi-hole y
											elimine la concesión DHCP si es necesario. Luego, también en Pi-hole, revise en Herramientas -> Red para ver si puede encontrar los hosts recurrentes allí.
											Si es así, elimínelos también allí. Ahora puede volver a iniciar Pi.Alert. Ahora el dispositivo(s) no debería aparecer más.
											Si dicho dispositivo sigue apareciendo repetidamente, se puede agregar la dirección MAC a la lista de ignorados <span class="text-maroon help_faq_code">MAC_IGNORE_LIST</span> en el archivo <span class="text-maroon help_faq_code">pialert.conf</span>.';
$pia_lang['HelpFAQ_Cat_Detail_300_head'] = '¿Qué significa? ';
$pia_lang['HelpFAQ_Cat_Detail_300_text_a'] = 'significa un dispositivo de red creado a partir de la página de red.';
$pia_lang['HelpFAQ_Cat_Detail_300_text_b'] = 'designa el número de puerto en el que el dispositivo editado actualmente está conectado a este dispositivo de red.';
$pia_lang['HelpFAQ_Cat_Detail_301_head_a'] = '¿Cuándo está escaneando ahora? En ';
$pia_lang['HelpFAQ_Cat_Detail_301_head_b'] = ' dice 1min pero el gráfico muestra intervalos de 5min.';
$pia_lang['HelpFAQ_Cat_Detail_301_text'] = 'El intervalo de tiempo entre los escaneos está definido por el "Cronjob", que está configurado en 5 minutos de forma predeterminada.  La designación "1min" se refiere a la duración esperada del escaneo.
											Dependiendo de la configuración de la red, este tiempo puede variar. Para editar el cronjob, puede utilizar el siguiente comando en la terminal/consola <span class="text-maroon help_faq_code">crontab -e</span>
        									y cambiar el intervalo.';
$pia_lang['HelpFAQ_Cat_Detail_302_head_a'] = '¿Qué significa? ';
$pia_lang['HelpFAQ_Cat_Detail_302_head_b'] = '¿y por qué no puedo seleccionarlo?';
$pia_lang['HelpFAQ_Cat_Detail_302_text'] = 'Algunos dispositivos modernos generan direcciones MAC aleatorias por razones de privacidad, que ya no pueden asociarse a ningún fabricante y que vuelven a cambiar con cada nueva conexión.
											Pi.Alert detecta si se trata de una dirección MAC aleatoria y activa este "campo" automáticamente. Para deshabilitar este comportamiento, debe buscar en su dispositivo cómo deshabilitar la
        									aleatorización de direcciones MAC.';
$pia_lang['HelpFAQ_Cat_Detail_303_head'] = '¿Qué es Nmap y para qué sirve?';
$pia_lang['HelpFAQ_Cat_Detail_303_text'] = 'Nmap es un escáner de red con múltiples capacidades.<br>
        									Cuando aparece un nuevo dispositivo en su lista, tiene la posibilidad de obtener información más detallada sobre el dispositivo a través del escaneo de Nmap.';
$pia_lang['HelpFAQ_Cat_Presence_400_head'] = 'Los dispositivos se muestran con un marcador amarillo y la nota "evento faltante".';
$pia_lang['HelpFAQ_Cat_Presence_400_text'] = 'Si esto sucede, tiene la opción de eliminar los eventos en el dispositivo en cuestión (vista de detalles).  Otra posibilidad sería encender el dispositivo y esperar hasta que Pi.Alert detecte el dispositivo como "online" con el siguiente
											escaneo y luego simplemente apagar el dispositivo nuevamente.  Ahora Pi.Alert debería anotar correctamente el estado del dispositivo en la base de datos con el próximo escaneo.';
$pia_lang['HelpFAQ_Cat_Presence_401_head'] = 'Un dispositivo se muestra como presente aunque esté "Offline".';
$pia_lang['HelpFAQ_Cat_Presence_401_text'] = 'Si esto sucede, tiene la posibilidad de eliminar los eventos del dispositivo en cuestión (vista de detalles).  Otra posibilidad sería encender el dispositivo y esperar hasta que Pi.Alert reconozca el dispositivo como "online" con el siguiente escaneo
											y luego simplemente apagar el dispositivo nuevamente.  Ahora Pi.Alert debería anotar correctamente el estado del dispositivo en la base de datos con el próximo escaneo.';
$pia_lang['HelpFAQ_Cat_Network_600_head'] = '¿Para qué sirve esta sección?';
$pia_lang['HelpFAQ_Cat_Network_600_text'] = 'Esta sección debería ofrecerle la posibilidad de mapear la asignación de sus dispositivos de red.  Para ello, puede crear uno o más conmutadores, WLAN, enrutadores, etc., proporcionarles un número de puerto si es necesario y asignarles dispositivos
											ya detectados. Esta asignación se realiza en la vista detallada del dispositivo a asignar.  Por lo tanto, es posible determinar rápidamente a qué puerto está conectado un host y si está en línea. Es posible asignar un dispositivo a múltiples
											 puertos (agrupación de puertos), así como múltiples dispositivos a un puerto (máquinas virtuales).';
$pia_lang['HelpFAQ_Cat_Network_601_head'] = 'How does the network page work?';
$pia_lang['HelpFAQ_Cat_Network_601_text'] = 'On the network side, for example, a switch is created. For this purpose, I already offer corresponding devices in the selection list. You continue to specify the type and the number of ports.<br><br>
											 On the detail view you have now, with each recognized device, the possibility to save this just created switch and the occupied port.<br><br>
											 Now the network page shows you the switch with its ports and the devices connected to it. For each device in the detail view, you have the option of assigning multiple ports to a switch, which you separate with a comma (e.g. for link aggregation). It is also possible to assign several devices to one port (e.g. a server with several virtual machines).<br><br>
											 You can also assign a switch to a router if you have created it on the network side. Normally, this switch will now be displayed on the router tab. What does not happen is that the router is displayed on the switch port. For this it is necessary and possible to save a manual port configuration. To do this, open the "Administration" and select the switch in the editing. After you have entered the type and the number of ports again, you have a selection list of possible devices in the lowest field. After the selection, only the MAC address is visible, followed by a ",". Now simply add the port of the router on the switch and save. It is also possible to enter multiple MAC addresses and ports. It is important to follow the syntax "MAC1,PortA;MAC2,PortB;MAC3,PortC".';
$pia_lang['HelpFAQ_Cat_Network_602_head'] = 'A switch or router is shown to me without ports.';
$pia_lang['HelpFAQ_Cat_Network_602_text'] = 'It is possible that the number of ports was not entered when the device was created on the network page. When editing the device on the network page, it is also necessary to enter an already entered number of ports again.<br>
											 If the number of ports is missing for a device that has already been created, the problem should be solved by editing the device and specifying the ports, the type and, if necessary, the manual port configuration.';
$pia_lang['HelpFAQ_Cat_Service_700_head'] = 'What do the different colors in the colored bar mean?';
$pia_lang['HelpFAQ_Cat_Service_700_text'] = 'There are 5 different color codes in total: <br>
											 <span style="background-color:lightgray;">&nbsp;&nbsp;&nbsp;</span> - no scan available yet<br>
											 <span class="bg-green">&nbsp;&nbsp;&nbsp;</span> - HTTP status code 2xx<br>
											 <span class="bg-yellow">&nbsp;&nbsp;&nbsp;</span> - HTTP status code 3xx-4xx<br>
											 <span class="bg-orange-custom">&nbsp;&nbsp;&nbsp;</span> - HTTP status code 5xx<br>
											 <span class="bg-red">&nbsp;&nbsp;&nbsp;</span> - offline';
$pia_lang['HelpFAQ_Cat_Service_701_head'] = 'What are the HTTP status codes?';
// from json
$pia_lang['HelpFAQ_Cat_Service_702_head'] = 'What changes are reported?';
$pia_lang['HelpFAQ_Cat_Service_702_text'] = 'Detectable events are:<br>
												<ul>
													<li>Changing the HTTP status code</li>
													<li>Change IP</li>
													<li>Response time of the server or the missing of the response.</li>
												</ul>
											 Depending on the choice of notification, either everything is reported, or only the absence of a server response.';
$pia_lang['HelpFAQ_Cat_Service_703_head'] = 'General information about "Web Service Monitoring".';
$pia_lang['HelpFAQ_Cat_Service_703_text'] = 'The monitoring is based exclusively on the responses of HTTP requests sent to the page. Depending on the state of the server, meaningful error patterns can be detected here. If the server does not respond at all, this is considered as "Down/Offline". These web server requests are performed every 10 min as part of the normal scan.';
$pia_lang['HelpFAQ_Cat_ServiceDetails_750_head'] = 'I cannot edit all the fields.';
$pia_lang['HelpFAQ_Cat_ServiceDetails_750_text'] = 'Not every field that is displayed on this page can be edited. Editable fields are:
													<ul>
														<li>' . $pia_lang['WebServices_label_Tags'] . '</li>
														<li>' . $pia_lang['WebServices_label_MAC'] . ' (possibly a device to which this web service is assigned)<br>
															A MAC address is expected here. If something else (e.g. "laptop") is entered here, "' . $pia_lang['WebServices_unknown_Device'] . ' (laptop)" appears in the overview..
															Services without this entry are listed under "' . $pia_lang['WebServices_BoxTitle_General'] . '".</li>
														<li>CheckBox: ' . $pia_lang['WebServices_Events_all'] . '</li>
														<li>CheckBox: ' . $pia_lang['WebServices_Events_down'] . '</li>
													</ul>';

//////////////////////////////////////////////////////////////////
// Reports Page
//////////////////////////////////////////////////////////////////

$pia_lang['Reports_Title'] = 'Notificaciones';
$pia_lang['Reports_delete_all'] = 'Borrar todas las notificaciones';
$pia_lang['Reports_delete_all_noti'] = 'Borrar todas las notificaciones';
$pia_lang['Reports_delete_all_noti_text'] = 'Se borran todas las notificaciones. El contador se pone a cero.';
$pia_lang['Reports_Rogue_hint'] = 'Un nuevo mensaje sobre un servidor DHCP desconocido sólo se muestra después de haber borrado este mensaje.';

//////////////////////////////////////////////////////////////////
// UpdateCheck
//////////////////////////////////////////////////////////////////

$pia_lang['Maintenance_Tools_Updatecheck'] = 'Verificar actualizaciones';
$pia_lang['Maintenance_Github_package_a'] = 'Última versión: ';
$pia_lang['Maintenance_Github_package_b'] = 'hora';
$pia_lang['Updatecheck_Title'] = 'Comprobación de actualizaciones';
$pia_lang['Updatecheck_cur'] = 'Versión actual de Pi.Alert utilizada';
$pia_lang['Updatecheck_new'] = 'Última versión de Pi.Alert en Github';
$pia_lang['GeoLiteDB_Title'] = 'Notas de la base de datos GeoLite2';
$pia_lang['GeoLiteDB_cur'] = 'Base de datos GeoLite2 cargada el';
$pia_lang['GeoLiteDB_new'] = 'Última base de datos GeoLite2 en Github';
$pia_lang['Updatecheck_RN'] = 'Notas de actualización de Pi.Alert';
$pia_lang['Updatecheck_U2D'] = 'Ya estás utilizando la última versión';
$pia_lang['Updatecheck_RN2'] = 'Pi.Alert Update Check';
$pia_lang['GeoLiteDB_button_del'] = 'Eliminar base de datos GeoLite2';
$pia_lang['GeoLiteDB_button_ins'] = 'Instalar base de datos GeoLite2';
$pia_lang['GeoLiteDB_credits'] = 'La base de datos se descarga desde <a href="https://github.com/P3TERX/GeoLite.mmdb" target="_blank">github.com/P3TERX/GeoLite.mmdb</a>. La base de datos GeoLite2 es un producto de <a href="https://dev.maxmind.com/geoip/geolite2-free-geolocation-data" target="_blank">MaxMind</a>.';
$pia_lang['GeoLiteDB_Installnotes'] = 'You can install the database via the ' . $pia_lang['WebServices_Tab_Graph'] . ' tab on the details page of any web service.';
$pia_lang['GeoLiteDB_absent'] = 'DB not installed';

//////////////////////////////////////////////////////////////////
// System Info Page
//////////////////////////////////////////////////////////////////

$pia_lang['SysInfo_storage_note'] = 'Es posible que no se pueda determinar el uso de memoria para todas las unidades enumeradas anteriormente. Esto depende del usuario bajo el cual están montadas las unidades.';

// =============================================================================================================

$pia_journ_lang['Journal_TableHead_Class'] = 'Método';
$pia_journ_lang['Journal_TableHead_Trigger'] = 'Desencadenador';

$pia_journ_lang['Title'] = 'Registro de Aplicación';
$pia_journ_lang['File_hash'] = 'pialert.conf - Hash';
// Frontend
$pia_journ_lang['a_000'] = 'Archivo de Configuración';
$pia_journ_lang['a_001'] = 'Acceso a GUI';
$pia_journ_lang['a_002'] = 'Escaneos de Pi.Alert';
$pia_journ_lang['a_005'] = 'Configuración de GUI';
$pia_journ_lang['a_010'] = 'Mantenimiento de BD';
$pia_journ_lang['a_020'] = 'Dispositivos';
$pia_journ_lang['a_021'] = 'Editor Múltiple';
$pia_journ_lang['a_025'] = 'Herramientas';
$pia_journ_lang['a_030'] = 'Monitoreo del Servicio Web';
$pia_journ_lang['a_031'] = 'ICMP Monitoring';
$pia_journ_lang['a_032'] = 'Main Scan';
$pia_journ_lang['a_040'] = 'Descripción de la Red';
$pia_journ_lang['a_050'] = 'Informes';
$pia_journ_lang['a_060'] = 'Verificación de Actualizaciones';
$pia_journ_lang['a_070'] = 'API';
// pialert-cli
$pia_journ_lang['b_002'] = $pia_journ_lang['a_002'];
$pia_journ_lang['b_010'] = 'Mantenimiento de BD';
$pia_journ_lang['b_030'] = $pia_journ_lang['a_030'];
$pia_journ_lang['b_031'] = $pia_journ_lang['a_031'];
$pia_journ_lang['b_032'] = $pia_journ_lang['a_032'];
//cronjob
$pia_journ_lang['c_002'] = $pia_journ_lang['a_002'];
$pia_journ_lang['c_010'] = $pia_journ_lang['a_010'];
// LogStrings
$pia_journ_lang['LogStr_0001'] = 'Entrada agregada';
$pia_journ_lang['LogStr_0002'] = 'Entrada editada';
$pia_journ_lang['LogStr_0003'] = 'Entrada eliminada';
$pia_journ_lang['LogStr_0004'] = 'Entrada editada (con error)';
$pia_journ_lang['LogStr_0005'] = 'Entrada eliminada (con error)';
$pia_journ_lang['LogStr_0006'] = 'Último cambio de archivo de configuración revertido';
$pia_journ_lang['LogStr_0007'] = 'Copia de seguridad de la configuración creada';
$pia_journ_lang['LogStr_0008'] = 'Base de datos GeoLite2 instalada';
$pia_journ_lang['LogStr_0009'] = 'Base de datos GeoLite2 eliminada';
$pia_journ_lang['LogStr_0010'] = 'Base de datos actualizada';
$pia_journ_lang['LogStr_0011'] = 'Copia de seguridad de la base de datos creada';
$pia_journ_lang['LogStr_0012'] = 'Copia de seguridad de la base de datos restaurada';
$pia_journ_lang['LogStr_0013'] = 'Limpieza de copias de seguridad (archivo de configuración y base de datos)';
$pia_journ_lang['LogStr_0014'] = 'Eliminar hosts inactivos (con error)';
$pia_journ_lang['LogStr_0015'] = 'Eliminar hosts inactivos';
$pia_journ_lang['LogStr_0016'] = 'Eliminar todos los hosts sin dirección MAC';
$pia_journ_lang['LogStr_0017'] = 'Eliminar todos los hosts sin dirección MAC (con error)';
$pia_journ_lang['LogStr_0018'] = 'Eliminar todos los hosts (unknown)';
$pia_journ_lang['LogStr_0019'] = 'Eliminar todos los hosts (unknown) (con error)';
$pia_journ_lang['LogStr_0020'] = 'Eliminar todos los eventos de un dispositivo';
$pia_journ_lang['LogStr_0021'] = 'Eliminar todos los eventos de un dispositivo (con error)';
$pia_journ_lang['LogStr_0022'] = 'Eliminar todos los hosts de la lista de dispositivos';
$pia_journ_lang['LogStr_0023'] = 'Eliminar todos los hosts de la lista de dispositivos (con error)';
$pia_journ_lang['LogStr_0024'] = 'Eliminar todos los eventos';
$pia_journ_lang['LogStr_0025'] = 'Eliminar todos los eventos (con error)';
$pia_journ_lang['LogStr_0026'] = 'Restablecer la actividad de la red';
$pia_journ_lang['LogStr_0027'] = 'Restablecer la actividad de la red (con error)';
$pia_journ_lang['LogStr_0030'] = 'Se agregó componente de red activo (Switch, Router, etc.)';
$pia_journ_lang['LogStr_0031'] = 'Se editó componente de red activo (Switch, Router, etc.)';
$pia_journ_lang['LogStr_0032'] = 'Se eliminó componente de red activo (Switch, Router, etc.)';
$pia_journ_lang['LogStr_0033'] = 'Se agregó dispositivo no escaneable (Hubs, dispositivos PoE, Docker, etc.)';
$pia_journ_lang['LogStr_0034'] = 'Se editó dispositivo no escaneable (Hubs, dispositivos PoE, Docker, etc.)';
$pia_journ_lang['LogStr_0035'] = 'Se eliminó dispositivo no escaneable (Hubs, dispositivos PoE, Docker, etc.)';
$pia_journ_lang['LogStr_0050'] = 'Protección de contraseña de Pi.Alert habilitada';
$pia_journ_lang['LogStr_0051'] = 'Protección de contraseña de Pi.Alert deshabilitada';
$pia_journ_lang['LogStr_0052'] = 'Se cambió la configuración de columnas de la lista de dispositivos';
$pia_journ_lang['LogStr_0053'] = 'Se cambió el tema';
$pia_journ_lang['LogStr_0054'] = 'Se cambió el idioma';
$pia_journ_lang['LogStr_0055'] = $pia_lang['BackDevices_darkmode_disabled'];
$pia_journ_lang['LogStr_0056'] = $pia_lang['BackDevices_darkmode_enabled'];
$pia_journ_lang['LogStr_0057'] = $pia_lang['BackDevices_onlinehistorygraph_disabled'];
$pia_journ_lang['LogStr_0058'] = $pia_lang['BackDevices_onlinehistorygraph_enabled'];
$pia_journ_lang['LogStr_0061'] = 'Actualización de Pi.Alert disponible';
$pia_journ_lang['LogStr_0062'] = 'No hay actualización de Pi.Alert disponible';
$pia_journ_lang['LogStr_0063'] = 'Actualización de la base de datos GeoLite2 disponible';
$pia_journ_lang['LogStr_0064'] = 'No hay actualización de la base de datos GeoLite2 disponible';
$pia_journ_lang['LogStr_0065'] = 'Base de datos GeoLite2 no instalada';
$pia_journ_lang['LogStr_0101'] = 'Base de datos limpiada y optimizada';
$pia_journ_lang['LogStr_0210'] = 'Escaneo individual de nmap realizado';
$pia_journ_lang['LogStr_0251'] = 'Ejecutado Wake-on-lan';
$pia_journ_lang['LogStr_0255'] = 'Ejecutado Speedtest en línea';
$pia_journ_lang['LogStr_0301'] = $pia_lang['BackDevices_webservicemon_enabled'];
$pia_journ_lang['LogStr_0302'] = $pia_lang['BackDevices_webservicemon_disabled'];
$pia_journ_lang['LogStr_0500'] = 'Notificación(es) de prueba enviada(s)';
$pia_journ_lang['LogStr_0503'] = 'Informe eliminado';
$pia_journ_lang['LogStr_0504'] = 'Eliminar todos los informes';
$pia_journ_lang['LogStr_0510'] = 'Pi.Alert reactivado';
$pia_journ_lang['LogStr_0511'] = 'Pi.Alert desactivado (con especificación de tiempo)';
$pia_journ_lang['LogStr_0512'] = 'Pi.Alert desactivado (durante 10 minutos)';
$pia_journ_lang['LogStr_0700'] = 'Clave API establecida';
$pia_journ_lang['LogStr_9001'] = 'Inicio de acceso a la interfaz web';
$pia_journ_lang['LogStr_9002'] = 'Cierre de sesión realizado';
$pia_journ_lang['LogStr_9003'] = 'Error de inicio de sesión (¡contraseña incorrecta!)';
$pia_journ_lang['LogStr_9004'] = 'Inicio de acceso a la interfaz web (con cookie)';
$pia_journ_lang['LogStr_9991'] = $pia_lang['BackDevices_MainScan_enabled'];
$pia_journ_lang['LogStr_9992'] = $pia_lang['BackDevices_MainScan_disabled'];
$pia_journ_lang['LogStr_9999'] = 'Archivo de configuración editado';

?>
